package widebase.rq.interface

import java.util.Map

import msgpack.rpcx.interface.AuthInterface

/** Consumer interface for consumers.
 *
 * @author myst3r10n
 */
trait ConsumerInterface extends ControlInterface {

  override def login(username: String, password: String): String
  override def logout(authId: String)

  /** Indicate ready to receive.
   *
   * @param authId of consumer
   *
   * @return bytes of records
   */
  def next(authId: String): Array[Byte]

  override def remoteShutdown(authId: String)

  /** Request rollback information.
   *
   * @param authId of consumer
   *
   * @return pair of records/partition
   */
  def rollback(authId: String): Map[String, String]

  /** Subscribe table.
   *
   * @param authId of consumer
   * @param name of table
   * @param selector to filter records
   */
  def subscribe(
    authId: String,
    name: String,
    selector: String = null)

  /** Unsubscribe table.
   *
   * @param authId of consumer
   */
  def unsubscribe(authId: String)

}

